@@ -188,6 +188,7 @@ impl Pizarra {
         }
     }
 
+
     fn handle_tool_button_released(&mut self, point: Vec2DScreen, tool_override: Option<SelectedTool>) -> Action {
         let transformed_point = self.transform.to_world_coordinates(point);
 
@@ -199,14 +200,20 @@ impl Pizarra {
                     ShapeFinished::No
                 };
 
-                if let ShapeFinished::Yes(shape) = finished {
-                    let shape_id = self.storage.add(shape);
+                match finished {
+                    ShapeFinished::Yes(shape) => {
+                        let shape_id = self.storage.add(shape);
 
-                    self.current_shape = None;
+                        self.current_shape = None;
 
-                    Action::Draw(shape_id)
-                } else {
-                    Action::Unfinished
+                        Action::Draw(shape_id)
+                    },
+                    ShapeFinished::Cancelled => {
+                        self.current_shape = None;
+
+                        Action::Empty
+                    },
+                    ShapeFinished::No => Action::Unfinished,
                 }
             },
             SelectedTool::Eraser => {
@@ -370,6 +377,10 @@ impl Pizarra {
         Pizarra::new(Vec2DScreen::new(80.0, 60.0), Default::default())
     }
 
+    pub fn set_config(&mut self, config: Config) {
+        self.config = config;
+    }
+
     /// Returns a transform object needed for proper rendering. This object can
     /// translate a point from storage coordinates to screen coordinates.
     pub fn get_transform(&self) -> Transform {
@@ -619,10 +630,8 @@ impl Pizarra {
 
         match key {
             Key::Escape => {
-                if self.current_shape.is_some() {
-                    self.current_shape = None;
-                    self.board_state = BoardState::Idle;
-                }
+                self.current_shape = None;
+                self.board_state = BoardState::Idle;
 
                 ShouldRedraw::All
             }
@@ -1121,6 +1130,8 @@ mod tests {
     fn cache_invalidation_on_ctrl_z() {
         let mut app = Pizarra::new_for_testing();
 
+        app.config.point_snap_radius = 1.0;
+
         app.resize(Vec2DScreen::new(10.0, 10.0));
 
         app.set_tool(SelectedTool::Shape(ShapeTool::Rectangle));
@@ -1176,6 +1187,8 @@ mod tests {
         // it's expeceted for the eraser not to erase the shape
         let mut app = Pizarra::new_for_testing();
 
+        app.config.point_snap_radius = 1.0;
+
         app.set_tool(SelectedTool::Shape(ShapeTool::Rectangle));
 
         // draw a shape
